"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Contact = void 0;
var util_1 = require("./util");
/* eslint-disable camelcase */
var binding = require('../binding');
var debug = require('debug')('deltachat:node:contact');
/**
 * Wrapper around dc_contact_t*
 */
var Contact = /** @class */ (function () {
    function Contact(dc_contact) {
        this.dc_contact = dc_contact;
        debug('Contact constructor');
    }
    Contact.prototype.toJson = function () {
        debug('toJson');
        return {
            address: this.getAddress(),
            color: this.color,
            authName: this.authName,
            status: this.status,
            displayName: this.getDisplayName(),
            id: this.getId(),
            name: this.getName(),
            profileImage: this.getProfileImage(),
            nameAndAddr: this.getNameAndAddress(),
            isBlocked: this.isBlocked(),
            isVerified: this.isVerified(),
        };
    };
    Contact.prototype.getAddress = function () {
        return binding.dcn_contact_get_addr(this.dc_contact);
    };
    Object.defineProperty(Contact.prototype, "authName", {
        /** Get original contact name.
         * This is the name of the contact as defined by the contact themself.
         * If the contact themself does not define such a name,
         * an empty string is returned. */
        get: function () {
            return binding.dcn_contact_get_auth_name(this.dc_contact);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Contact.prototype, "color", {
        get: function () {
            return util_1.integerToHexColor(binding.dcn_contact_get_color(this.dc_contact));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Contact.prototype, "status", {
        /**
         * contact's status
         *
         * Status is the last signature received in a message from this contact.
         */
        get: function () {
            return binding.dcn_contact_get_status(this.dc_contact);
        },
        enumerable: false,
        configurable: true
    });
    Contact.prototype.getDisplayName = function () {
        return binding.dcn_contact_get_display_name(this.dc_contact);
    };
    Contact.prototype.getId = function () {
        return binding.dcn_contact_get_id(this.dc_contact);
    };
    Contact.prototype.getName = function () {
        return binding.dcn_contact_get_name(this.dc_contact);
    };
    Contact.prototype.getNameAndAddress = function () {
        return binding.dcn_contact_get_name_n_addr(this.dc_contact);
    };
    Contact.prototype.getProfileImage = function () {
        return binding.dcn_contact_get_profile_image(this.dc_contact);
    };
    Contact.prototype.isBlocked = function () {
        return Boolean(binding.dcn_contact_is_blocked(this.dc_contact));
    };
    Contact.prototype.isVerified = function () {
        return Boolean(binding.dcn_contact_is_verified(this.dc_contact));
    };
    return Contact;
}());
exports.Contact = Contact;
//# sourceMappingURL=contact.js.map